@@ -54,8 +54,6 @@
 #include "gpm-icon-names.h"
 #include "egg-console-kit.h"
 
-#define GPM_BACKLIGHT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BACKLIGHT, GpmBacklightPrivate))
-
 struct GpmBacklightPrivate
 {
 	UpClient		*client;
@@ -81,7 +79,7 @@ enum {
 
 static guint signals [LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GpmBacklight, gpm_backlight, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GpmBacklight, gpm_backlight, G_TYPE_OBJECT)
 
 /**
  * gpm_backlight_error_quark:
@@ -414,11 +412,7 @@ gpm_settings_key_changed_cb (GSettings *settings, const gchar *key, GpmBacklight
  * Does the actions when the ac power source is inserted/removed.
  **/
 static void
-#if UP_CHECK_VERSION(0, 99, 0)
 gpm_backlight_client_changed_cb (UpClient *client, GParamSpec *pspec, GpmBacklight *backlight)
-#else
-gpm_backlight_client_changed_cb (UpClient *client, GpmBacklight *backlight)
-#endif
 {
 	gpm_backlight_brightness_evaluate_and_set (backlight, FALSE, TRUE);
 }
@@ -723,8 +717,6 @@ gpm_backlight_class_init (GpmBacklightClass *klass)
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__UINT,
 			      G_TYPE_NONE, 1, G_TYPE_UINT);
-
-	g_type_class_add_private (klass, sizeof (GpmBacklightPrivate));
 }
 
 /**
@@ -738,7 +730,7 @@ gpm_backlight_class_init (GpmBacklightClass *klass)
 static void
 gpm_backlight_init (GpmBacklight *backlight)
 {
-	backlight->priv = GPM_BACKLIGHT_GET_PRIVATE (backlight);
+	backlight->priv = gpm_backlight_get_instance_private (backlight);
 
 	/* record our idle time */
 	backlight->priv->idle_timer = g_timer_new ();
@@ -750,13 +742,8 @@ gpm_backlight_init (GpmBacklight *backlight)
 
 	/* we use up_client for the ac-adapter-changed signal */
 	backlight->priv->client = up_client_new ();
-#if UP_CHECK_VERSION(0, 99, 0)
 	g_signal_connect (backlight->priv->client, "notify",
 			  G_CALLBACK (gpm_backlight_client_changed_cb), backlight);
-#else
-	g_signal_connect (backlight->priv->client, "changed",
-			  G_CALLBACK (gpm_backlight_client_changed_cb), backlight);
-#endif
 
 	/* gets caps */
 	backlight->priv->can_dim = gpm_brightness_has_hw (backlight->priv->brightness);
