@@ -66,7 +66,6 @@
 
 static void     gpm_manager_finalize	(GObject	 *object);
 
-#define GPM_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_MANAGER, GpmManagerPrivate))
 #define GPM_MANAGER_NOTIFY_TIMEOUT_NEVER	0 /* ms */
 #define GPM_MANAGER_NOTIFY_TIMEOUT_SHORT	10 * 1000 /* ms */
 #define GPM_MANAGER_NOTIFY_TIMEOUT_LONG		30 * 1000 /* ms */
@@ -117,7 +116,7 @@ typedef enum {
 	GPM_MANAGER_SOUND_LAST
 } GpmManagerSound;
 
-G_DEFINE_TYPE (GpmManager, gpm_manager, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GpmManager, gpm_manager, G_TYPE_OBJECT)
 
 /**
  * gpm_manager_error_quark:
@@ -947,11 +946,7 @@ gpm_manager_button_pressed_cb (GpmButton *button, const gchar *type, GpmManager
  * gpm_manager_client_changed_cb:
  **/
 static void
-#if UP_CHECK_VERSION(0, 99, 0)
 gpm_manager_client_changed_cb (UpClient *client, GParamSpec *pspec, GpmManager *manager)
-#else
-gpm_manager_client_changed_cb (UpClient *client, GpmManager *manager)
-#endif
 {
 	gboolean event_when_closed;
 	gint timeout;
@@ -1048,7 +1043,6 @@ gpm_manager_class_init (GpmManagerClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gpm_manager_finalize;
-	g_type_class_add_private (klass, sizeof (GpmManagerPrivate));
 }
 
 /**
@@ -1823,7 +1817,7 @@ gpm_manager_init (GpmManager *manager)
 	GDBusConnection *g_connection;
 	GError *error = NULL;
 
-	manager->priv = GPM_MANAGER_GET_PRIVATE (manager);
+	manager->priv = gpm_manager_get_instance_private (manager);
 	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	g_connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
 
@@ -1854,15 +1848,10 @@ gpm_manager_init (GpmManager *manager)
 	g_signal_connect (manager->priv->settings, "changed",
 			  G_CALLBACK (gpm_manager_settings_changed_cb), manager);
 	manager->priv->client = up_client_new ();
-#if UP_CHECK_VERSION(0, 99, 0)
 	g_signal_connect (manager->priv->client, "notify::lid-is-closed",
 			  G_CALLBACK (gpm_manager_client_changed_cb), manager);
 	g_signal_connect (manager->priv->client, "notify::on-battery",
 			  G_CALLBACK (gpm_manager_client_changed_cb), manager);
-#else
-	g_signal_connect (manager->priv->client, "changed",
-			  G_CALLBACK (gpm_manager_client_changed_cb), manager);
-#endif
 
 	/* use libmatenotify */
 	notify_init (GPM_NAME);
